@@ -49,6 +49,7 @@ import org.gnu.gtk.event.SpinListener;
 import org.gnu.gtk.event.TextBufferListener;
 import org.gnu.gtk.event.TextViewListener;
 import org.gnu.gtk.event.ToggleListener;
+import org.gnu.gtk.event.ToolButtonListener;
 import org.gnu.gtk.event.TreeSelectionListener;
 import org.gnu.gtk.event.TreeViewColumnListener;
 import org.gnu.gtk.event.TreeViewListener;
@@ -85,16 +86,19 @@ abstract class ListenerDelegate {
 	}
 
 	public boolean fireEvent(GtkEvent event, double value) {
+		Object[] params = null;
+		Object ret = null;
 		try {
 			Widget source = (Widget)event.getSource();
+			//System.err.println("fireEvent: source:"+source);
 			GtkEventType typeNeeded = source.getEventType(signal);
+			//System.err.println("fireEvent: typeNeeded:"+typeNeeded);
 			if (event.getType() == typeNeeded) {
 				Class[] paramTypes = handler.getParameterTypes();
-				Object[] params;
-				Object ret;
 
 				// handlers have optional event and target parameters
 				int n = paramTypes.length;
+				//System.err.println("fireEvent: n:"+n);
 				if (n == 2)
 					// <handler>(event, target);
 					params = new Object[] { event, target };
@@ -105,6 +109,7 @@ abstract class ListenerDelegate {
 					// <handler>();
 					params = new Object[0];
 
+				//System.err.println("fireEvent: owner:"+owner+", event:"+event+", target:"+target);
 				ret = handler.invoke(owner, params);
 
 				// return type is either null (if void) or boolean 
@@ -116,6 +121,8 @@ abstract class ListenerDelegate {
 			e.getTargetException().printStackTrace();
 		} catch (Exception e) {
 			System.err.println("ListenerDelegate.fireEvent(" + event + "): " + e);
+			e.printStackTrace();
+			System.err.println("params:"+params+", ret:"+ret);
 		}
 		return false;
 	}
@@ -173,5 +180,6 @@ abstract class ListenerDelegate {
 		delegateMap.put(DruidPageSetupListener.class, DruidPageDelegate.class);
 		delegateMap.put(FontPickerListener.class, FontPickerDelegate.class);
 		delegateMap.put(TreeViewListener.class, TreeViewDelegate.class);
+		delegateMap.put(ToolButtonListener.class, ToolButtonDelegate.class);
 	}
 }
